==> dateparser_1.0.0.orig.tar.gz: dateparser-1.0.0/dateparser/data/date_translation_data/se.py <==
info = {
    "name": "se",
    "date_order": "YMD",
    "january": [
        "ođđajagemánnu",
        "ođđj"
    ],
    "february": [
        "guovvamánnu",
        "guov"
    ],
    "march": [
        "njukčamánnu",
        "njuk"
    ],
    "april": [
        "cuoŋománnu",
        "cuo"
    ],
    "may": [
        "miessemánnu",
        "mies"
    ],
    "june": [
        "geassemánnu",
        "geas"
    ],
    "july": [
        "suoidnemánnu",
        "suoi"
    ],
    "august": [
        "borgemánnu",
        "borg"
    ],
    "september": [
        "čakčamánnu",
        "čakč"
    ],
    "october": [
        "golggotmánnu",
        "golg"
    ],
    "november": [
        "skábmamánnu",
        "skáb"
    ],
    "december": [
        "juovlamánnu",
        "juov"
    ],
    "monday": [
        "vuossárga",
        "vuos"
    ],
    "tuesday": [
        "maŋŋebárga",
        "maŋ"
    ],
    "wednesday": [
        "gaskavahkku",
        "gask"
    ],
    "thursday": [
        "duorasdat",
        "duor"
    ],
    "friday": [
        "bearjadat",
        "bear"
    ],
    "saturday": [
        "lávvardat",
        "láv"
    ],
    "sunday": [
        "sotnabeaivi",
        "sotn"
    ],
    "am": [
        "iđitbeaivi",
        "ib",
        "iđitbeaivet"
    ],
    "pm": [
        "eahketbeaivi",
        "eb",
        "eahketbeaivet"
    ],
    "year": [
        "jáhki"
    ],
    "month": [
        "mánnu"
    ],
    "week": [
        "váhkku"
    ],
    "day": [
        "beaivi"
    ],
    "hour": [
        "diibmu"
    ],
    "minute": [
        "minuhtta"
    ],
    "second": [
        "sekunda"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "ikte"
        ],
        "0 day ago": [
            "odne"
        ],
        "in 1 day": [
            "ihttin"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) jahki maŋŋilit",
            "(\\d+) jahkki maŋŋilit"
        ],
        "\\1 year ago": [
            "(\\d+) jahki árat",
            "(\\d+) jahkki árat"
        ],
        "in \\1 month": [
            "(\\d+) mánotbadji maŋŋilit"
        ],
        "\\1 month ago": [
            "(\\d+) mánotbadji árat"
        ],
        "in \\1 week": [
            "(\\d+) vahku maŋŋilit",
            "(\\d+) vahkku maŋŋilit"
        ],
        "\\1 week ago": [
            "(\\d+) vahku árat",
            "(\\d+) vahkku árat"
        ],
        "in \\1 day": [
            "(\\d+) jándor maŋŋilit",
            "(\\d+) jándora maŋŋilit"
        ],
        "\\1 day ago": [
            "(\\d+) jándor árat",
            "(\\d+) jándora árat"
        ],
        "in \\1 hour": [
            "(\\d+) diibmu maŋŋilit",
            "(\\d+) diibmur maŋŋilit"
        ],
        "\\1 hour ago": [
            "(\\d+) diibmu árat",
            "(\\d+) diibmur árat"
        ],
        "in \\1 minute": [
            "(\\d+) minuhta maŋŋilit",
            "(\\d+) minuhtta maŋŋilit"
        ],
        "\\1 minute ago": [
            "(\\d+) minuhta árat",
            "(\\d+) minuhtta árat"
        ],
        "in \\1 second": [
            "(\\d+) sekunda maŋŋilit",
            "(\\d+) sekundda maŋŋilit"
        ],
        "\\1 second ago": [
            "(\\d+) sekunda árat",
            "(\\d+) sekundda árat"
        ]
    },
    "locale_specific": {
        "se-FI": {
            "name": "se-FI",
            "monday": [
                "vuossárgga"
            ],
            "tuesday": [
                "maŋŋebárgga"
            ],
            "wednesday": [
                "gaskavahku"
            ],
            "thursday": [
                "duorastaga"
            ],
            "friday": [
                "bearjadaga"
            ],
            "saturday": [
                "lávvardaga"
            ],
            "year": [
                "jahki",
                "j"
            ],
            "week": [
                "vahkku"
            ],
            "relative-type": {
                "1 year ago": [
                    "mannan jagi"
                ],
                "0 year ago": [
                    "dán jagi"
                ],
                "in 1 year": [
                    "boahtte jagi"
                ]
            },
            "relative-type-regex": {
                "in \\1 year": [
                    "(\\d+) jagi siste"
                ],
                "\\1 year ago": [
                    "(\\d+) jagi árat"
                ]
            }
        },
        "se-SE": {
            "name": "se-SE"
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> dateparser-1.1.1.tar.gz: dateparser-1.1.1/dateparser/data/date_translation_data/se.py <==
info = {
    "name": "se",
    "date_order": "YMD",
    "january": [
        "ođđajagemánnu",
        "ođđj"
    ],
    "february": [
        "guov",
        "guovvamánnu"
    ],
    "march": [
        "njuk",
        "njukčamánnu"
    ],
    "april": [
        "cuo",
        "cuoŋománnu"
    ],
    "may": [
        "mies",
        "miessemánnu"
    ],
    "june": [
        "geas",
        "geassemánnu"
    ],
    "july": [
        "suoi",
        "suoidnemánnu"
    ],
    "august": [
        "borg",
        "borgemánnu"
    ],
    "september": [
        "čakč",
        "čakčamánnu"
    ],
    "october": [
        "golg",
        "golggotmánnu"
    ],
    "november": [
        "skáb",
        "skábmamánnu"
    ],
    "december": [
        "juov",
        "juovlamánnu"
    ],
    "monday": [
        "vuos",
        "vuossárga"
    ],
    "tuesday": [
        "maŋ",
        "maŋŋebárga"
    ],
    "wednesday": [
        "gask",
        "gaskavahkku"
    ],
    "thursday": [
        "duor",
        "duorasdat"
    ],
    "friday": [
        "bear",
        "bearjadat"
    ],
    "saturday": [
        "láv",
        "lávvardat"
    ],
    "sunday": [
        "sotn",
        "sotnabeaivi"
    ],
    "am": [
        "ib",
        "iđitbeaivet",
        "iđitbeaivi"
    ],
    "pm": [
        "eahketbeaivet",
        "eahketbeaivi",
        "eb"
    ],
    "year": [
        "jáhki"
    ],
    "month": [
        "mánnu"
    ],
    "week": [
        "váhkku"
    ],
    "day": [
        "beaivi"
    ],
    "hour": [
        "diibmu"
    ],
    "minute": [
        "minuhtta"
    ],
    "second": [
        "sekunda"
    ],
    "relative-type": {
        "0 day ago": [
            "odne"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "ikte"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "ihttin"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+) jándor árat",
            "(\\d+) jándora árat"
        ],
        "\\1 hour ago": [
            "(\\d+) diibmu árat",
            "(\\d+) diibmur árat"
        ],
        "\\1 minute ago": [
            "(\\d+) minuhta árat",
            "(\\d+) minuhtta árat"
        ],
        "\\1 month ago": [
            "(\\d+) mánotbadji árat"
        ],
        "\\1 second ago": [
            "(\\d+) sekunda árat",
            "(\\d+) sekundda árat"
        ],
        "\\1 week ago": [
            "(\\d+) vahkku árat",
            "(\\d+) vahku árat"
        ],
        "\\1 year ago": [
            "(\\d+) jahki árat",
            "(\\d+) jahkki árat"
        ],
        "in \\1 day": [
            "(\\d+) jándor maŋŋilit",
            "(\\d+) jándora maŋŋilit"
        ],
        "in \\1 hour": [
            "(\\d+) diibmu maŋŋilit",
            "(\\d+) diibmur maŋŋilit"
        ],
        "in \\1 minute": [
            "(\\d+) minuhta maŋŋilit",
            "(\\d+) minuhtta maŋŋilit"
        ],
        "in \\1 month": [
            "(\\d+) mánotbadji maŋŋilit"
        ],
        "in \\1 second": [
            "(\\d+) sekunda maŋŋilit",
            "(\\d+) sekundda maŋŋilit"
        ],
        "in \\1 week": [
            "(\\d+) vahkku maŋŋilit",
            "(\\d+) vahku maŋŋilit"
        ],
        "in \\1 year": [
            "(\\d+) jahki maŋŋilit",
            "(\\d+) jahkki maŋŋilit"
        ]
    },
    "locale_specific": {
        "se-FI": {
            "name": "se-FI",
            "monday": [
                "vuossárgga"
            ],
            "tuesday": [
                "maŋŋebárgga"
            ],
            "wednesday": [
                "gaskavahku"
            ],
            "thursday": [
                "duorastaga"
            ],
            "friday": [
                "bearjadaga"
            ],
            "saturday": [
                "lávvardaga"
            ],
            "year": [
                "j",
                "jahki"
            ],
            "week": [
                "vahkku"
            ],
            "relative-type": {
                "0 year ago": [
                    "dán jagi"
                ],
                "1 year ago": [
                    "mannan jagi"
                ],
                "in 1 year": [
                    "boahtte jagi"
                ]
            },
            "relative-type-regex": {
                "\\1 year ago": [
                    "(\\d+) jagi árat"
                ],
                "in \\1 year": [
                    "(\\d+) jagi siste"
                ]
            }
        },
        "se-SE": {
            "name": "se-SE"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
